laddu
=====

`laddu <https://github.com/denehoffman/laddu>`_ is an library for analyzing particle physics data. It is written in Rust with bindings to Python which are documented here.


.. toctree::
   :caption: Contents
   :maxdepth: 1
   :name: sec-api
   
   tutorials/index
   modules/index
